==> kdeadmin-3.5.1.tar.bz2: kdeadmin-3.5.1/knetworkconf/knetworkconf/knetworkconfmodule.h <==
/***************************************************************************
                          knetworkconfmodule.h  -  description
                             -------------------
    begin                : Tue Apr 1 2003
    copyright            : (C) 2003 by Juan Luis Baptiste
    email                : juancho@linuxmail.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNETWORKCONFMODULE_H
#define KNETWORKCONFMODULE_H

#include "knetworkconf.h"
#include <kaboutdata.h>
#include <kcmodule.h>

class KNetworkConfModule : public KCModule
{
  Q_OBJECT

public:
  KNetworkConfModule(QWidget* parent, const char *name/*, QStringList list*/);
  ~KNetworkConfModule();

  void load();
  void save();
  int buttons();

  bool useRootOnlyMsg() const;
  QString rootOnlyMsg() const;
  KAboutData* aboutData() const;
  QString quickHelp() const;

signals:
  void changed(bool state);

private:
  KNetworkConf* conf;
};

#endif

==> kdeadmin-4.2.1.tar.bz2: kdeadmin-4.2.1/knetworkconf/knetworkconf/knetworkconfmodule.h <==
/***************************************************************************
                          knetworkconfmodule.h  -  description
                             -------------------
    begin                : Tue Apr 1 2003
    copyright            : (C) 2003 by Juan Luis Baptiste
    email                : juancho@linuxmail.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNETWORKCONFMODULE_H
#define KNETWORKCONFMODULE_H

#include "knetworkconf.h"
#include <kaboutdata.h>
#include <kcmodule.h>
#include <KPluginFactory>
class KNetworkConfModule : public KCModule
{
  Q_OBJECT

public:
  explicit KNetworkConfModule(QWidget * parent = 0, const QVariantList &list = QVariantList());
  ~KNetworkConfModule();

  void load();
  void save();
  int buttons();

  bool useRootOnlyMsg() const;
  QString rootOnlyMsg() const;
  KAboutData* aboutData() const;
  QString quickHelp() const;

private slots:
  void configChanged(bool);

private:
  KNetworkConf* conf;
};

#endif
